========
ini2toml
========

**ini2toml** is a command line tool and Python library for automatically
converting |ini_cfg|_ files into a TOML_ equivalent.


Contents
========

.. toctree::
   :maxdepth: 2

   Overview <readme>
   setuptools_pep621

.. toctree::
   :caption: Project
   :maxdepth: 2

   Contributions & Help <contributing>
   dev-guide
   license
   authors

.. toctree::
   :maxdepth: 1

   Module Reference <api/modules>
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |ini_cfg| replace:: ``.ini/.cfg``

.. _ini_cfg: https://docs.python.org/3/library/configparser.html#supported-ini-file-structure
.. _TOML: https://toml.io/en/
